pub fn protocol_system_call<T: Transaction>(
tx: &T,
) -> Result<Option<ProtocolSystemCall>>Available on crate feature
monad only.Expand description
Converts a canonical Monad envelope into its dedicated system call.
Returns an error when the transaction uses Monad’s reserved protocol sender but does not satisfy the canonical envelope rules.